@@ -9,15 +9,15 @@
 #  ifndef LEATHERMAN_CURL_EXPORT
 #    ifdef leatherman_curl_EXPORTS
         /* We are building this library */
-#      define LEATHERMAN_CURL_EXPORT 
+#      define LEATHERMAN_CURL_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define LEATHERMAN_CURL_EXPORT 
+#      define LEATHERMAN_CURL_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef LEATHERMAN_CURL_NO_EXPORT
-#    define LEATHERMAN_CURL_NO_EXPORT 
+#    define LEATHERMAN_CURL_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -33,9 +33,10 @@
 #  define LEATHERMAN_CURL_DEPRECATED_NO_EXPORT LEATHERMAN_CURL_NO_EXPORT LEATHERMAN_CURL_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LEATHERMAN_CURL_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LEATHERMAN_CURL_NO_DEPRECATED
+#    define LEATHERMAN_CURL_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
